

TAPService
=======================

.. currentmodule:: pyvo.dal.tap

.. autoclass:: TAPService
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~TAPService.availability
      ~TAPService.available
      ~TAPService.capabilities
      ~TAPService.hardlimit
      ~TAPService.maxrec
      ~TAPService.tables
      ~TAPService.up_since
      ~TAPService.upload_methods

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~TAPService.run_async
      ~TAPService.run_sync
      ~TAPService.search
      ~TAPService.submit_job

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: availability
   .. autoattribute:: available
   .. autoattribute:: capabilities
   .. autoattribute:: hardlimit
   .. autoattribute:: maxrec
   .. autoattribute:: tables
   .. autoattribute:: up_since
   .. autoattribute:: upload_methods

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: run_async
   .. automethod:: run_sync
   .. automethod:: search
   .. automethod:: submit_job

   
   